# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: valutes_proto/get_dollar_rate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='valutes_proto/get_dollar_rate.proto',
  package='',
  syntax='proto3',
  serialized_pb=_b('\n#valutes_proto/get_dollar_rate.proto\"\x16\n\x14GetDollarRateRequest\"+\n\x15GetDollarRateResponse\x12\x12\n\nvalue_rate\x18\x01 \x01(\x02\x32I\n\x07GetRate\x12>\n\rGetDollarRate\x12\x15.GetDollarRateRequest\x1a\x16.GetDollarRateResponseb\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GETDOLLARRATEREQUEST = _descriptor.Descriptor(
  name='GetDollarRateRequest',
  full_name='GetDollarRateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=61,
)


_GETDOLLARRATERESPONSE = _descriptor.Descriptor(
  name='GetDollarRateResponse',
  full_name='GetDollarRateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_rate', full_name='GetDollarRateResponse.value_rate', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=106,
)

DESCRIPTOR.message_types_by_name['GetDollarRateRequest'] = _GETDOLLARRATEREQUEST
DESCRIPTOR.message_types_by_name['GetDollarRateResponse'] = _GETDOLLARRATERESPONSE

GetDollarRateRequest = _reflection.GeneratedProtocolMessageType('GetDollarRateRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDOLLARRATEREQUEST,
  __module__ = 'valutes_proto.get_dollar_rate_pb2'
  # @@protoc_insertion_point(class_scope:GetDollarRateRequest)
  ))
_sym_db.RegisterMessage(GetDollarRateRequest)

GetDollarRateResponse = _reflection.GeneratedProtocolMessageType('GetDollarRateResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETDOLLARRATERESPONSE,
  __module__ = 'valutes_proto.get_dollar_rate_pb2'
  # @@protoc_insertion_point(class_scope:GetDollarRateResponse)
  ))
_sym_db.RegisterMessage(GetDollarRateResponse)


# @@protoc_insertion_point(module_scope)
